.. _scripting_examples:

Examples
========

A collection of examples are presented to supplement the tutorial. The
examples below are identical to the Jupyter Notebook in the ``examples``
folder of the repository
`here <https://github.com/cuihantao/andes/tree/master/examples>`__. You
can run the examples in a live Jupyter Notebook online using
`Binder <https://mybinder.org/v2/gh/cuihantao/andes/master>`__.

.. toctree::
   :maxdepth: 2
   :caption: Scripting

   ../_examples/ex1.ipynb
   ../_examples/ex2.ipynb
   ../_examples/ex3.ipynb
   ../_examples/ex4.ipynb
   ../_examples/ex5.ipynb
   ../_examples/ex6.ipynb
   ../_examples/ex7.ipynb
   ../_examples/ex8.ipynb
   ../_examples/ex9.ipynb
   ../_examples/ex10.ipynb

.. toctree::
   :maxdepth: 2
   :caption: Interoperability

   matpower.ipynb
   pandapower.ipynb
   pypowsybl.ipynb
